pub fn parse_snbt_argument(input: &str) -> Result<(NbtTag, usize), SnbtError>Expand description
Parses one SNBT tag and returns the byte cursor consumed by that tag.
Unlike parse_snbt, this does not consume trailing whitespace after the
tag. Command parsers use the returned cursor so the command graph can own
node-separating whitespace.
Errors
Returns an error when the input does not start with a valid SNBT tag.