parse_snbt_compound_argument

Function parse_snbt_compound_argument 

pub fn parse_snbt_compound_argument(
    input: &str,
) -> Result<(NbtCompound, usize), SnbtError>
Parses one SNBT compound and returns the byte cursor consumed by it.

Errors

Returns an error when the input does not start with a valid SNBT compound.